@@ -87,14 +87,12 @@ class Mail
 public:
   enum CryptState
     {
-      NoCryptMail,
-      NeedsFirstAfterWrite,
-      NeedsActualCrypt,
-      NeedsUpdateInOOM,
-      NeedsSecondAfterWrite,
-      NeedsUpdateInMAPI,
-      WantsSendInline,
-      WantsSendMIME,
+      NotStarted, /* The mail has not been encrypted or signed by us */
+      DataCollected, /* Data from the OOM / MAPI has been collected */
+      BackendDone, /* GnuPG is finished */
+      OOMUpdated, /* GnuPG Data has been written to OOM */
+      OOMSynced, /* OOM has been synced internally but not MAPI */
+      CryptFinished, /* The mail is signed and or encrypted and can be sent */
     };
 
   /** @brief Construct a mail object for the item.
@@ -123,6 +121,17 @@ public:
   */
   static Mail* getMailForUUID (const char *uuid);
 
+  /** @brief Search for all Mail objects with the uuid. This
+    does not use the UUID map as the uuid map assumes tht
+    uuids are unique. The mails are searched in the general
+    mail map.
+
+    This can be used to find copies of the same mail. An
+    empty uuid retuns all mails without a uuid set by us.
+
+    @returns All mails with the same uuid. */
+  static std::vector<Mail *> searchMailsByUUID (const std::string &uuid);
+
   /** @brief Get the last created mail.
 
     @returns A reference to the last created mail or null.
@@ -378,9 +387,11 @@ public:
   const std::string & getUUID () const { return m_uuid; }
 
   /** Returns 0 on success if the mail has a uid alrady or sets
-    the uid. Setting only succeeds if the OOM is currently
+    the uid.
+    If reset is true the mail will get a new UUID.
+    Setting only succeeds if the OOM is currently
     accessible. Returns -1 on error. */
-  int setUUID_o ();
+  int setUUID_o (bool reset = false);
 
   /** Returns a localized string describing in one or two
     words the crypto status of this mail. */
@@ -674,19 +685,14 @@ public:
      and so on and then send the multiple mails. */
   void splitAndSend_o ();
 
-  /* A callback for another mail that was created as
-     a split from us. */
-  void splitCopyMailCallback (Mail *copy);
-
   /* Reset recipient and resolved key data. */
   void resetRecipients ();
 
-  /* Returns true if a mail is a copy that was split of
-     a different mail. */
-  bool isSplitCopy () const;
+  /* Returns the mail object of which this mail is a copy */
+  Mail *copyParent () const;
 
   /* Setter for isSplitCopy */
-  void setSplitCopy (bool val);
+  void setCopyParent (Mail *parent);
 
   /* Set protected headers data */
   void setProtectedHeaders (const std::string &hdrs);
@@ -701,17 +707,29 @@ public:
 
   /* Get the original body of the mail. */
   const std::string &getOriginalBody () const;
+
+  /* Get the plain attachments for an encrypt / sign operation. Set through
+     updateOOMData_o */
+  std::vector <std::shared_ptr <Attachment> > plainAttachments() const;
+
+  /* True if this is a multipart related mail, 1 if all attachments are
+     related, 2 if there is a related and a mixed attachment. */
+  int isMultipartRelated () const;
+
+  /* Set an additional item ref to this object. Different API calls
+     in outlook can return different LPDISPATCH pointer to the same
+     OOM Mailitem. The additional ref will be released on delete. */
+  void setAdditionalReference (LPDISPATCH ref);
 private:
-  /* Returns a copy of the mailitem object. This copy
-     is sadly not the same as in the ItemLoad event
-     so we cannot find it in our map of mailitems. */
-  LPDISPATCH copy ();
+  /* Returns a copy of the mail object. */
+  Mail *copy ();
   bool checkIfMailMightBePrinting_o ();
   void updateSigstate ();
   int add_attachments_o (std::vector<std::shared_ptr<Attachment> > attachments);
   int buildProtectedHeaders_o ();
 
   LPDISPATCH m_mailitem;
+  LPDISPATCH m_additional_item;
   LPDISPATCH m_event_sink;
   LPDISPATCH m_currentItemRef;
   bool m_processed,    /* The message has been porcessed by us.  */
@@ -768,14 +786,11 @@ private:
   std::string m_gpgol_class; /* The GpgOL Message class */
   std::vector<GpgME::Key> m_resolved_signing_keys; /* Prepared / resolved keys for signing. */
   bool m_recipients_set; /* Recipients were explictly set. */
-  bool m_is_split_copy; /* Is the a copy mail that was part of a split. */
+  Mail *m_copy_parent; /* The mail object of which this mail is a copy */
   std::string m_protected_headers;
   header_info_s m_header_info; /* Information about the original headers */
   bool m_attachs_added; /* State variable to track if we have added attachments to this mail. */
   std::string m_dec_content_type; /* Top level content type of the decrypted mail. */
+  std::vector <std::shared_ptr <Attachment> > m_plain_attachments; /* Attachments to encrypt */
 };
-
-/* A state variable to capture which mail triggered a copy to
-   use our own objects in the ItemLoad event. */
-extern Mail *g_mail_copy_triggerer;
 #endif // MAIL_H
